@@ -49,9 +49,10 @@ class Classes_meta(type):
         'fdi.dataset.arraydataset': ['ArrayDataset', 'Column', 'MediaWrapper'],
         'fdi.dataset.dataset': ['GenericDataset', 'CompositeDataset'],
         'fdi.dataset.tabledataset': ['TableDataset', 'IndexedTableDataset'],
+        'fdi.dataset.unstructureddataset': ['UnstrcturedDataset'],
         'fdi.dataset.readonlydict': ['ReadOnlyDict'],
         'fdi.pal.context': ['AbstractContext', 'Context',
-                            'AbstractMapContext', 'MapContext',
+                            'MapContext',
                             'RefContainer',
                             'ContextRuleException'],
         'fdi.pal.urn': ['Urn'],
