@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from .serializable import serialize
+from .serializable import serialize, ATTR, LEN_ATTR
 from .odict import ODict
 from .classes import Classes
 from ..utils.common import lls, trbk
@@ -15,7 +15,7 @@ from collections import ChainMap
 import builtins
 import urllib
 from collections import UserDict
-from collections.abc import MutableMapping as MM, MutableSequence as MS, MutableSet as MS
+from collections.abc import MutableMapping as MM, MutableSequence as MS, MutableSet as MSe
 import sys
 if sys.version_info[0] >= 3:  # + 0.1 * sys.version_info[1] >= 3.3:
     PY3 = True
@@ -41,8 +41,8 @@ def constructSerializable(obj, lookup=None, debug=False):
     variables.
     Objects to be deserialized must have their classes loaded.
     _STID cannot have module names in it (e.g.  dataset.Product)
-    or locals()[classname] or globals()[classname] will not work. See alternative in
-    https://stackoverflow.com/questions/452969/does-python-have-an-equivalent-to-java-class-forname
+    or locals()[classname] or globals()[classname] will not work.
+
     Parameters
     ----------
 
@@ -90,9 +90,22 @@ def constructSerializable(obj, lookup=None, debug=False):
             print(spaces + 'Find non-_STID. <%s>' % classname)
         inst = obj
     else:
-        classname = obj['_STID']
-        if debug:
-            print(spaces + 'Find _STID <%s>' % classname)
+        ostid = obj['_STID']
+        # check escape case
+        if ostid.startswith('0'):
+            # escape
+            inst = obj
+            # classname = ostid[1:]
+            # inst['_STID'] = classname
+            if debug:
+                print(spaces + 'Find _STID <%s>. Take as <%s>.' %
+                      (ostid, classname))
+            indent -= 1
+            return inst
+        else:
+            classname = ostid
+            if debug:
+                print(spaces + 'Find _STID <%s>.' % (ostid))
         # process types wrapped in a dict
         if PY3:
             if classname == 'bytes':
@@ -161,16 +174,32 @@ def constructSerializable(obj, lookup=None, debug=False):
                         desv = v
 
         # set k with desv
+        icn = inst.__class__.__name__
+        dcn = desv.__class__.__name__
         if issubclass(inst.__class__, (MM)):    # should be object_pairs_hook
-            inst[k] = desv
-            if debug:
-                print(spaces + 'Set dict/usrd <%s>[%s] = %s <%s>' %
-                      ((inst.__class__.__name__), str(k), lls(desv, 70), (desv.__class__.__name__)))
+            if k.startswith(ATTR):
+                k2 = k[LEN_ATTR:]
+                setattr(inst, k2, desv)
+                if debug:
+                    print(spaces + 'Set attrbute to dict/usrd <%s>.%s = %s <%s>' %
+                          (icn, str(k2), lls(desv, 70), dcn))
+            else:
+                inst[k] = desv
+                if debug:
+                    print(spaces + 'Set member to dict/usrd <%s>[%s] = %s <%s>' %
+                          (icn, str(k), lls(desv, 70), dcn))
         else:
-            setattr(inst, k, desv)
-            if debug:
-                print(spaces + 'set non-dict <%s>.%s = %s <%s>' %
-                      ((inst.__class__.__name__), str(k), lls(desv, 70), (desv.__class__.__name__)))
+            if k.startswith(ATTR):
+                k2 = k[LEN_ATTR:]
+                setattr(inst, k2, desv)
+                if debug:
+                    print(spaces + 'set attribute to non-dict <%s>.%s = %s <%s>' %
+                          (icn, str(k2), lls(desv, 70), dcn))
+            else:
+                setattr(inst, k, desv)
+                if debug:
+                    print(spaces + 'set attribute to non-dict <%s>.%s = %s <%s>' %
+                          (icn, str(k), lls(desv, 70), dcn))
     indent -= 1
     return inst
 
