@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 
-from collections import namedtuple, OrderedDict
+from collections import namedtuple, OrderedDict, UserList
 from .serializable import Serializable
+from .annotatable import Annotatable
 from .eq import DeepEqual
-from ..utils.common import trbk
+from ..utils.common import trbk, lls
 
 
 import logging
@@ -12,12 +13,12 @@ logger = logging.getLogger(__name__)
 # logger.debug('level %d' %  (logger.getEffectiveLevel()))
 
 
-class EventListener(object):
+class EventListener(Annotatable):
     """ Generic interface for listeners that will listen to anything
     """
 
-    def __init__(self, **kwds):
-        super().__init__(**kwds)
+    def __init__(self, *args, **kwds):
+        super().__init__(*args, **kwds)  # EventListener
 
     def targetChanged(self,  *args, **kwargs):
         """ Informs that an event has happened in a target of
@@ -31,7 +32,7 @@ class EventListener(object):
         pass
 
 
-class DatasetBaseListener(EventListener):
+class xDatasetBaseListener(Annotatable):
     """ Generic interface for listeners that will listen to events
     happening on a target of a specific type.
     Java Warning:
@@ -39,6 +40,17 @@ class DatasetBaseListener(EventListener):
     hard reference.
     """
 
+    def __init__(self, *args, **kwds):
+        """
+
+        Parameters
+        ----------
+
+        Returns
+        -------
+        """
+        super().__init__(*args, **kwds)  # DatasetBaseListener
+
     def targetChanged(self, event):
         """ Informs that an event has happened in a target of the
         specified type.
@@ -54,20 +66,22 @@ class DatasetBaseListener(EventListener):
         pass
 
 
-class ListnerSet(Serializable, DeepEqual, list):
+class ListnerSet(Serializable, DeepEqual, UserList):
     """ Mutable collection of Listeners of an EvenSender.
     """
 
-    def __init__(self, **kwds):
+    def __init__(self, data=None, *args, **kwds):
         """
         Parameters
         ----------
+        :data: default is `None` for a list.
 
         Returns
         -----
         """
-        self._members = []
-        super(ListnerSet, self).__init__(**kwds)
+        if data is None:
+            data = []
+        super().__init__(data, *args, **kwds)
 
     @property
     def urns(self):
@@ -119,7 +133,7 @@ class ListnerSet(Serializable, DeepEqual, list):
         """
 
         ret = [ProductRef(
-            x).urn for x in self._members if remove is None or x != remove]
+            x).urn for x in self.data if remove is None or x != remove]
 
         return ret
 
@@ -143,26 +157,47 @@ class ListnerSet(Serializable, DeepEqual, list):
         """
         return OrderedDict()
 
-    def toString(self, level=0, **kwds):
+    def __repr__(self, **kwds):
+
+        return self.toString(level=2)
+
+    def toString(self, level=0, alist=False, **kwds):
         """
         Parameters
         ----------
 
         Returns
         -------
+        LIST[TUPLE(OBJ)] or STRXS
+        A list of member-repre tuples or a string of all depending on `alist`.
         """
+
         if level == 0:
-            l = ['%s(%d, %s)' % (x.__class__.__name__, id(x),
-                                 lls(x.description, 20))
-                 for x in self._members]
+            if alist:
+                l = [(x.__class__.__name__, id(x),
+                      lls((x.description if hasattr(x, 'description') else 'UNKNOWN'), 20))
+                     for x in self.data]
+            else:
+                l = ['%s(%d, %s)' % (x.__class__.__name__, id(x),
+                                     lls((x.description if hasattr(x, 'description') else 'UNKNOWN'), 20))
+                     for x in self.data]
+
         else:
-            l = ['%s(%d, %s)' % (x.__class__.__name__, id(x),
-                                 lls(x.description, 8))
-                 for x in self._members]
-        return self.__class__.__name__ + '{' + ', '.join(l) + '}'
+            if alist:
+                l = [(x.__class__.__name__, id(x),
+                      lls((x.description if hasattr(x, 'description') else 'UNKNOWN'), 8))
+                     for x in self.data]
+            else:
+                l = ['%s(%d, %s)' % (x.__class__.__name__, id(x),
+                                     lls((x.description if hasattr(x, 'description') else 'UNKNOWN'), 8))
+                     for x in self.data]
+        if alist:
+            return l
+        else:
+            return self.__class__.__name__ + '(' + ', '.join(l) + ')'
 
 
-class EventSender(object):
+class EventSender():
     """ adapted from Peter Thatcher's
     https://stackoverflow.com/questions/1092531/event-system-in-python/1096614#1096614
     """
@@ -175,8 +210,9 @@ class EventSender(object):
         Returns
 
         """
+
         self._listeners = ListnerSet()
-        super(EventSender, self).__init__(**kwds)
+        super().__init__(**kwds)  # EventSender
 
     @property
     def listeners(self):
@@ -212,8 +248,9 @@ class EventSender(object):
 
         """
         self._listeners = ListnerSet()
-        for listener in listeners:
-            self.addListener(listener)
+        if listeners:
+            for listener in listeners:
+                self.addListener(listener)
 
     def getListeners(self):
         """ Returns the current Listeners.
@@ -299,7 +336,7 @@ class EventSender(object):
 
 
 class DatasetEventSender(EventSender):
-    def __init__(self, **kwds):
+    def __init__(self, **kwds):  # DatasetEventSender
         """
         Paremeters
         ----------
@@ -309,7 +346,7 @@ class DatasetEventSender(EventSender):
 
         """
 
-        super(DatasetEventSender, self).__init__(**kwds)
+        super().__init__(**kwds)  # DatasetEventSender
 
 
 EventTypes = [
@@ -400,7 +437,7 @@ class DatasetEvent(Serializable):
         # The first event in the chain that provoked this event,
         # or null if this event is its own root.
         self.rootCause = rootCause
-        super(DatasetEvent, self).__init__(**kwds)
+        super().__init__(**kwds)  # DatasetEvent
 
     def toString(self, level=0, **kwds):
         return self.__repr__()
@@ -423,7 +460,7 @@ class DatasetEvent(Serializable):
         return s
 
 
-class ParameterListener(DatasetBaseListener):
+class ParameterListener(EventListener):
     """ Listener for events occuring in a Parameter.
     Available types::
 
@@ -438,8 +475,19 @@ class ParameterListener(DatasetBaseListener):
     """
     pass
 
+    def __init__(self, **kwds):
+        """
 
-class MetaDataListener(DatasetBaseListener):
+        Parameters
+        ----------
+
+        Returns
+        -------
+        """
+        super().__init__(**kwds)
+
+
+class MetaDataListener(EventListener):
     """ Listener for events occuring in MetaData.
     Available types::
 
@@ -456,8 +504,19 @@ class MetaDataListener(DatasetBaseListener):
     create an object hard reference. See DatasetBaseListener.
     """
 
+    def __init__(self, *args, **kwds):
+        """
 
-class DatasetListener(DatasetBaseListener):
+        Parameters
+        ----------
+
+        Returns
+        -------
+        """
+        super().__init__(*args, **kwds)
+
+
+class DatasetListener(EventListener):
     """ Listener for events occuring in MetaData.
     Available types::
 
@@ -475,8 +534,19 @@ class DatasetListener(DatasetBaseListener):
     create an object hard reference. See DatasetBaseListener.
     """
 
+    def __init__(self, **kwds):
+        """
 
-class ColumnListener(DatasetBaseListener):
+        Parameters
+        ----------
+
+        Returns
+        -------
+        """
+        super().__init__(**kwds)  # DatasetListener
+
+
+class ColumnListener(EventListener):
     """ Listener for events occuring in a Column.
 
     Available types::
@@ -488,8 +558,19 @@ class ColumnListener(DatasetBaseListener):
     Cause is always null.
     """
 
+    def __init__(self, **kwds):
+        """
 
-class ProductListener(DatasetBaseListener):
+        Parameters
+        ----------
+
+        Returns
+        -------
+        """
+        super().__init__(**kwds)  # ColumnListener
+
+
+class ProductListener(EventListener):
     """ Listener for events occuring in Product.
     Available types::
 
@@ -506,3 +587,14 @@ class ProductListener(DatasetBaseListener):
     Warning: The listener handler must be a class attribute in order to
     create an object hard reference. See DatasetBaseListener.
     """
+
+    def __init__(self, **kwds):
+        """
+
+        Parameters
+        ----------
+
+        Returns
+        -------
+        """
+        super().__init__(**kwds)  # ProductListener
