@@ -1,19 +1,18 @@
 # -*- coding: utf-8 -*-
 
-from ..utils.masked import masked
-from ..utils.common import grouper
-from ..utils.ydump import ydump
 from .serializable import Serializable
 from .datatypes import DataTypes, DataTypeNames
 from .odict import ODict
 from .composite import Composite
-from .listener import DatasetEventSender, ParameterListener, DatasetListener, DatasetEvent, EventTypeOf
+from .listener import DatasetEventSender, ParameterListener, DatasetEvent, EventTypeOf
 from .eq import DeepEqual, xhash
 from .copyable import Copyable
 from .annotatable import Annotatable
 from .classes import Classes
 from .typed import Typed
 from .invalid import INVALID
+from ..utils.masked import masked
+from ..utils.common import grouper
 from ..utils.common import exprstrs, wls, bstr, t2l
 
 from tabulate import tabulate
@@ -26,7 +25,13 @@ import logging
 logger = logging.getLogger(__name__)
 # logger.debug('level %d' %  (logger.getEffectiveLevel()))
 
-
+"""
+| Attribute | Defining Module | Holder Variable |
+| 'description' | `Annotatable` | `description` |
+| 'typ_' | `Typed` | `_type` |
+| 'unit' | `Quantifiable` | '_unit' |
+| 'typecode' | `Typecoded` | '_typecode' |
+"""
 Parameter_Attr_Defaults = {
     'AbstractParameter': dict(
         value=None,
@@ -158,7 +163,7 @@ class AbstractParameter(Annotatable, Copyable, DeepEqual, DatasetEventSender, Se
         self.setValue(value)
 
     def getValue(self):
-        """ Gets the value of this parameter as an Object. 
+        """ Gets the value of this parameter as an Object.
         Parameters
         ----------
 
@@ -260,7 +265,7 @@ class AbstractParameter(Annotatable, Copyable, DeepEqual, DatasetEventSender, Se
             return super(AbstractParameter, self).__lt__(obj)
 
     def __gt__(self, obj):
-        """ can compare value 
+        """ can compare value
         Parameters
         ----------
 
@@ -274,7 +279,7 @@ class AbstractParameter(Annotatable, Copyable, DeepEqual, DatasetEventSender, Se
             return super(AbstractParameter, self).__gt__(obj)
 
     def __le__(self, obj):
-        """ can compare value 
+        """ can compare value
         Parameters
         ----------
 
@@ -287,7 +292,7 @@ class AbstractParameter(Annotatable, Copyable, DeepEqual, DatasetEventSender, Se
             return super(AbstractParameter, self).__le__(obj)
 
     def __ge__(self, obj):
-        """ can compare value 
+        """ can compare value
         Parameters
         ----------
 
@@ -300,7 +305,7 @@ class AbstractParameter(Annotatable, Copyable, DeepEqual, DatasetEventSender, Se
             return super(AbstractParameter, self).__ge__(obj)
 
     def getValueAsString():
-        """ Value as string for building the string representation of the parameter. 
+        """ Value as string for building the string representation of the parameter.
         Parameters
         ----------
 
@@ -337,7 +342,7 @@ class AbstractParameter(Annotatable, Copyable, DeepEqual, DatasetEventSender, Se
         return self.__class__.__name__ + ss
 
     def __getstate__(self):
-        """ Can be encoded with serializableEncoder 
+        """ Can be encoded with serializableEncoder
         Parameters
         ----------
 
@@ -740,15 +745,15 @@ f        With two positional arguments: arg1-> value, arg2-> description. Parame
         if alist:
             return ret
         vs, us, ts, ds, fs, gs, cs = ret
-        if level:
-            return vs
-        return '%s{ %s <%s>, "%s", default= %s, valid= %s tcode=%s}' % \
-            (self.__class__.__name__, vs, ts, ds, fs, gs, cs)
+        if level > 1:
+            return '(%s: %s <%s>)' % (ts, vs, us)
+        return '%s(%s: %s <%s>, "%s", default= %s, valid= %s tcode=%s)' % \
+            (self.__class__.__name__, ts, vs, us, ds, fs, gs, cs)
 
     __str__ = toString
 
     def __getstate__(self):
-        """ Can be encoded with serializableEncoder. 
+        """ Can be encoded with serializableEncoder.
         Parameters
         ----------
 
@@ -769,7 +774,7 @@ MetaHeaders = ['name', 'value', 'unit', 'type', 'valid',
                'default', 'code', 'description']
 
 
-class MetaData(Composite, Copyable, Serializable, ParameterListener, DatasetEventSender):
+class MetaData(ParameterListener, Composite, Copyable, DatasetEventSender):
     """ A container of named Parameters. A MetaData object can
     have one or more parameters, each of them stored against a
     unique name. The order of adding parameters to this container
@@ -779,8 +784,8 @@ class MetaData(Composite, Copyable, Serializable, ParameterListener, DatasetEven
     will keep the order. """
 
     Table_Widths = [
-        {'name': 15, 'value': 20, 'unit': 7, 'type': 8,
-         'valid': 20, 'default': 17, 'code': 4, 'description': 21}
+        {'name': 15, 'value': 18, 'unit': 6, 'type': 8,
+         'valid': 17, 'default': 15, 'code': 4, 'description': 17}
     ]
 
     def __init__(self, copy=None, defaults=None, **kwds):
@@ -793,7 +798,7 @@ class MetaData(Composite, Copyable, Serializable, ParameterListener, DatasetEven
         -------
         """
 
-        super(MetaData, self).__init__(**kwds)
+        super().__init__(**kwds)
         if copy:
             # not implemented ref https://stackoverflow.com/questions/10640642/is-there-a-decent-way-of-creating-a-copy-constructor-in-python
             raise ValueError('use copy.copy() insteadof MetaData(copy)')
@@ -813,7 +818,7 @@ class MetaData(Composite, Copyable, Serializable, ParameterListener, DatasetEven
         visitor.visit(self)
 
     def clear(self):
-        """ Removes all the key - parameter mappings. 
+        """ Removes all the key - parameter mappings.
         Parameters
         ----------
 
@@ -832,13 +837,19 @@ class MetaData(Composite, Copyable, Serializable, ParameterListener, DatasetEven
         -------
         """
         if not issubclass(newParameter.__class__, AbstractParameter):
-            raise TypeError('Only Parameters can be saved.')
+            if name == 'listeners' and issubclass(newParameter.__class__, list):
+                pass
+            elif name == '_STID' and issubclass(newParameter.__class__, str):
+                pass
+            else:
+                raise TypeError('Only Parameters can be saved. %s is a %s.' %
+                                (name, newParameter.__class__.__name__))
 
         super(MetaData, self).set(name, newParameter)
 
         if 'listeners' in self.__dict__:
-            so, ta, ty, ch, ca, ro = self, self, -1, \
-                (name, newParameter), None, None
+            so, ta, ty, ch, ca, ro = self, self, -1,
+            (name, newParameter), None, None
             if name in self.keySet():
                 ty = EventType.PARAMETER_CHANGED
             else:
@@ -853,7 +864,7 @@ class MetaData(Composite, Copyable, Serializable, ParameterListener, DatasetEven
         return self.toString(level=3)
 
     def remove(self, name):
-        """ add eventhandling 
+        """ add eventhandling
         Parameters
         ----------
 
@@ -896,14 +907,32 @@ class MetaData(Composite, Copyable, Serializable, ParameterListener, DatasetEven
         cn = self.__class__.__name__
         s = ''
         att = {}
-        for (k, v) in self._sets.items():
-            att['name'] = str(k)
+        has_omission = False
+
+        for (k, v) in self.__getstate__().items():
+            if k.startswith('_ATTR_'):
+                k = k[6:]
+            elif k == '_STID':
+                continue
+            att['name'] = k
             # limit cell width for level=0,1
-            att['value'], att['unit'], att['type'], att['description'],\
-                att['default'], att['valid'], att['code'] = v.toString(
-                    level=level, width=0 if level > 1 else 1,
-                    tablefmt=tablefmt, tablefmt1=tablefmt1, tablefmt2=tablefmt2,
-                    alist=True)
+            if issubclass(v.__class__, Parameter):
+                att['value'], att['unit'], att['type'], att['description'],\
+                    att['default'], att['valid'], att['code'] = v.toString(
+                        level=level, width=0 if level > 1 else 1,
+                        tablefmt=tablefmt, tablefmt1=tablefmt1, tablefmt2=tablefmt2,
+                        alist=True)
+            else:
+                # listeners
+                lstr = v.toString(level=level, alist=True)
+                if len(lstr) < 3:
+                    lstr = [["", "<No listener>", ""]]
+                att['value'], att['unit'], att['type'], att['description'] = \
+                    '\n'.join(str(x[1]) for x in lstr), '', \
+                    '\n'.join(x[0] for x in lstr), \
+                    '\n'.join(x[2] for x in lstr)
+                att['default'], att['valid'], att['code'] = '', '', ''
+
             if level == 0:
                 l = tuple(att[n] for n in MetaHeaders) if param_widths == -1 else \
                     tuple(wls(att[n], w)
@@ -924,13 +953,18 @@ class MetaData(Composite, Copyable, Serializable, ParameterListener, DatasetEven
             else:
                 n = att['name']
                 if n in self._defaults and self._defaults[n]['default'] == v.value:
+
+                    has_omission = True
                     pass
+                elif n == 'listeners' and len(v) == 0:
+                    has_omission = True
                 else:
-                    ps = '%s=%s' % (att['name'], att['value'])
-                    #tab.append(wls(ps, 80//N))
+                    ps = '%s=%s' % (att['name'], v.toString(level))
+                    # tab.append(wls(ps, 80//N))
                     tab.append(ps)
 
-                # tab.append(att['name'])
+        if has_omission:
+            tab.append('..')
 
         # write out the table
         if level == 0:
@@ -947,25 +981,16 @@ class MetaData(Composite, Copyable, Serializable, ParameterListener, DatasetEven
                           disable_numparse=True)
         else:
             s = ', '.join(tab) if len(tab) else 'Default Meta'
-            if len(self.listeners):
-                l = ', listeners = %s' % \
-                    self.listeners.toString(level=level,
-                                            tablefmt=tablefmt, tablefmt1=tablefmt1,
-                                            tablefmt2=tablefmt2,
-                                            **kwds)
-            else:
-                l = '.'
-            return s + l
-        lsnr = self.listeners.toString(level=level,
-                                       tablefmt=tablefmt, tablefmt1=tablefmt1,
-                                       tablefmt2=tablefmt2,
-                                       **kwds)
+            l = '.'
+            return '<' + self.__class__.__name__ + ' ' + s + l + '>'
 
-        return '\n%s\n%s-listeners = %s' % (s, cn, lsnr) if len(tab) else \
-            '%s %s-listeners = %s' % ('(No Parameter.)', cn, lsnr)
+        return '\n%s' % (s) if len(tab) else '(No Parameter.)'
+
+        # return '\n%s\n%s-listeners = %s' % (s, cn, lsnr) if len(tab) else \
+        #    '%s %s-listeners = %s' % ('(No Parameter.)', cn, lsnr)
 
     def __getstate__(self):
-        """ Can be encoded with serializableEncoder 
+        """ Can be encoded with serializableEncoder
         Parameters
         ----------
 
@@ -976,6 +1001,6 @@ class MetaData(Composite, Copyable, Serializable, ParameterListener, DatasetEven
         # print(self.listeners)
         # print([id(o) for o in self.listeners])
 
-        return OrderedDict(_sets=self._sets,
-                           listeners=self.listeners,
+        return OrderedDict(**self.data,
+                           _ATTR_listeners=self.listeners,
                            _STID=self._STID)
