@@ -67,14 +67,15 @@ class ODict(UserDict, Serializable, DeepEqual):
     #             kk = tuple(item[0])
     #             self[kk] = item[1]
 
-    def toString(self, level=0,
-                 tablefmt='rst', tablefmt1='simple', tablefmt2='simple',
-                 matprint=None, trans=True, **kwds):
+    def toString(self, level=0, keyval=None, **kwds):
         """
 
         Parameters
         ----------
-
+        :level:  default=0,
+        :keyval: default=`None`. If set to a string, `ODict` class name is not shown and a label of given string is shown with each key as 'label key:\n'.
+        :tablefmt: ='rst', tablefmt1='simple', tablefmt2='simple',
+                 matprint=None, trans=True, heavy=True
         Returns
         -------
         """
@@ -85,27 +86,65 @@ class ODict(UserDict, Serializable, DeepEqual):
         # return ydump(self.data)
 
         OD_toString_Nest += 1
-        d = '<ODict '
+        label = '' if keyval is None else keyval
+        d = '' if keyval else '<OD '
         for n, v in self.data.items():
-            #d += '    ' * OD_toString_Nest + '[ ' + str(n) + ' ]= '
-            d += 'Label: "' + str(n) + '":' + '\n' if level < 2 else ' '
-            s = bstr(v, level=level,
-                     tablefmt=tablefmt, tablefmt1=tablefmt1, tablefmt2=tablefmt2,
-                     matprint=matprint, trans=trans, **kwds)
+            d += f'{label} "{n}":\n' if level < 2 else ' '
+            s = bstr(v, level=level, **kwds)
             d = d + s
         OD_toString_Nest -= 1
-        return d + '>'
+        return d + '' if keyval else '>'
 
     def get(self, name):
-        """ Raise a ``KeyErrpr`` to change the default behavior of colections.Mapping to quietly return a None when a key is not found in the dict.
+        """ Raise a ``KeyError`` to change the default behavior of colections.Mapping to quietly return a None when a key is not found in the dict.
         """
 
         return self.data[name]
-        res = super().__getitem__(name)
-        if res is not None or name in self.data:
-            return res
-        logger.debug('%s is not found in %s.' % (name, self))
-        raise KeyError()
+        # res = super().__getitem__(name)
+        # if res is not None or name in self.data:
+        #     return res
+        # msg = '%s is not found in %s.' % (name, self)
+        # logger.debug(msg)
+        # raise KeyError(msg)
+
+    def __getitem__(self, name):
+        """
+        For collections.abc.MutableMapping.
+
+        Parameters
+        ----------
+
+        Returns
+        -------
+
+        """
+        return self.data[name]
+
+    def __setitem__(self, name, value):
+        """
+        For collections.abc.MutableMapping.
+
+        Parameters
+        ----------
+
+        Returns
+        -------
+
+        """
+        self.data[name] = value
+
+    def __delitem__(self, name):
+        """
+        For collections.abc.MutableMapping.
+
+        Parameters
+        ----------
+
+        Returns
+        -------
+
+        """
+        del self.data[name]
 
     # def __repr__(self):
     #     """ returns string representation with details set according to debuglevel.
@@ -124,7 +163,7 @@ class ODict(UserDict, Serializable, DeepEqual):
 
         """
         return OrderedDict(
-            data=self.data,
+            **self.data,
             _STID=self._STID
         )
 
