@@ -175,6 +175,7 @@ class SerializableEncoder(json.JSONEncoder):
 
 def serialize(o, cls=None, **kwds):
     """ return JSON using special encoder SerializableEncoder 
+
     Parameterts
     -----------
 
@@ -186,11 +187,15 @@ def serialize(o, cls=None, **kwds):
     return json.dumps(o, cls=cls, **kwds)
 
 
-class Serializable(object):
+ATTR = '_ATTR_'
+LEN_ATTR = len(ATTR)
+
+
+class Serializable():
     """ mh: Can be serialized.
     Has a _STID  instance property to show its class information. """
 
-    def __init__(self, **kwds):
+    def __init__(self, *args, **kwds):
         """
 
         Parameters
@@ -199,8 +204,7 @@ class Serializable(object):
         Returns
         -------
         """
-
-        super(Serializable, self).__init__(**kwds)
+        super().__init__(*args, **kwds)
         sc = self.__class__
         # print('@@@ ' + sc.__name__, str(issubclass(sc, dict)))
         if 0 and issubclass(sc, dict):
@@ -213,6 +217,7 @@ class Serializable(object):
         Parameters
         ----------
 
+
         Returns
         -------
         """
@@ -228,7 +233,7 @@ class Serializable(object):
         return self.__class__.__name__ + '(' + co + ')'
 
     def __getstate__(self):
-        """ returns an odict that has all state info of this object.
+        """ returns an ordered ddict that has all state info of this object.
         Subclasses should override this function.
         Parameters
         ----------
@@ -238,6 +243,26 @@ class Serializable(object):
         """
         raise NotImplementedError()
 
+    def __prettystate__(self):
+        """ returns a better-looking ggetstate.
+
+        Parameters
+        ----------
+
+        Returns
+        -------
+        dictview of a mappingg of a string representation of `k` and the original `v`.
+
+        """
+        res = {}
+        for k, v in self.__getstate__().items():
+            if k == '_STID':
+                continue
+            sk = str(k)
+            bk = sk[LEN_ATTR:] if sk.startswith(ATTR) else sk
+            res[bk] = v
+        return res.items()
+
     def __setstate__(self, state):
         """
         Parameters
@@ -246,8 +271,16 @@ class Serializable(object):
         Returns
         -------
         """
-        for name in self.__getstate__().keys():
-            self.__setattr__(name, state[name])
+        for name in state.keys():
+            if name.startswith(ATTR):
+                k2 = name[LEN_ATTR:]
+                self.__setattr__(k2, state[name])
+            elif name == '_STID':
+                pass
+            elif hasattr(self, '__setitem__'):
+                self[name] = state[name]
+            else:
+                self.__setattr__(name, state[name])
 
     def __reduce_ex__(self, protocol):
         """
@@ -275,5 +308,8 @@ class Serializable(object):
     def serializable(self):
         """ Can be encoded with serializableEncoder """
         s = copy.copy(self.__getstate__())
+        # make sure _STID is the last, for pools to ID data.
+        if '_STID' in s:
+            del s['_STID']
         s.update({'_STID': self._STID})
         return s
