@@ -4,7 +4,7 @@ from .indexed import Indexed
 from .ndprint import ndprint
 from .odict import ODict
 from ..utils.common import mstr, bstr, lls, exprstrs, findShape
-from .dataset import Dataset
+from .dataset import Dataset, make_title_meta_l0, CompositeDataset
 from .indexed import Indexed
 
 try:
@@ -39,7 +39,7 @@ logger = logging.getLogger(__name__)
 # logger.debug('level %d' %  (logger.getEffectiveLevel()))
 
 
-class TableModel(object):
+class TableModel():
     """ to interrogate a tabular data model
     """
 
@@ -47,7 +47,7 @@ class TableModel(object):
         """
 
         """
-        super(TableModel, self).__init__(**kwds)
+        super().__init__(**kwds)
 
     def getColumnClass(self, columnIndex):
         """ Returns the class for the first cell
@@ -94,7 +94,7 @@ class TableModel(object):
 MdpInfo = Model['metadata']
 
 
-class TableDataset(Dataset, TableModel):
+class TableDataset(CompositeDataset, TableModel):
     """  Special dataset that contains a single Array Data object.
     A TableDataset is a tabular collection of Columns. It is optimized to work on array data..
     The column-wise approach is convenient in many cases. For example, one has an event list, and each algorithm is adding a new field to the events (i.e. a new column, for example a quality mask).
@@ -144,19 +144,12 @@ class TableDataset(Dataset, TableModel):
                          **kwds)  # initialize data, meta, unit
         # self.setData(data)
 
-    def getData(self):
-        """ Optimized for _data being an ``ODict`` implemented with ``UserDict``.
+    # def getData(self):
+    #     """ Optimized for _data being an ``ODict/dict`` implemented with ``DataContaier``.
 
-        """
+    #     """
 
-        try:
-            return self._data.data
-        except AttributeError:
-            d = super().getData()
-            if hasattr(d, 'data'):
-                return self._data.data
-            else:
-                return d
+    #     return self._data
 
     def setData(self, data):
         """ sets name-column pairs from data.
@@ -474,13 +467,17 @@ Default is to return all columns.
                 key = ''
         self.addColumn(name=key, column=value)
 
+    def __iter__(self):
+        for x in self.getData():
+            yield x
+
     def items(self):
         """ for k,v in tabledataset.items()
         """
         return self.getData().items()
 
     def __getitem__(self, key):
-        """ return colmn if given key.
+        """ return colmn of given key.
 
         ref. ``getColumn()``.
         """
@@ -491,12 +488,29 @@ Default is to return all columns.
         """
         self.setColumn(key, value)
 
+    def __delitem__(self, key):
+        """ delete colmn of given key.
+
+        ref. ``removeColumn()``.
+        """
+        return self.removeColumn(key)
+
+    keys = TableModel.getColumnNames
+
+    #__len__ = TableModel.getColumnCount
+
+    # def __contains__(self, name):
+    #     """ if 'name` is found in column names.
+    #     """
+    #     return name in self.getData()
+
     def __repr__(self):
         return self.toString(level=2)
 
     def toString(self, level=0,
-                 tablefmt='rst', tablefmt1='simple', tablefmt2='simple',
-                 width=0, param_widths=None, matprint=None, trans=True, **kwds):
+                 tablefmt='grid', tablefmt1='simple', tablefmt2='simple',
+                 width=0, param_widths=None, matprint=None, trans=True,
+                 heavy=True, center=-1, **kwds):
         """
         tablefmt2: format of 2D data, others see `MetaData.toString`.
         """
@@ -504,8 +518,6 @@ Default is to return all columns.
             matprint = ndprint
 
         cn = self.__class__.__name__
-        s = '=== %s (%s) ===\n' % (cn, self.description if hasattr(
-            self, 'description') else '')
         if level > 1:
             s = cn + '('
             s += self.meta.toString(
@@ -515,36 +527,41 @@ Default is to return all columns.
                 **kwds)
             return s + 'data= {' + \
                 ', '.join('"%s": %s' % (k, v.toString(
-                    level=level,
+                    level=level, heavy=heavy,
                     tablefmt=tablefmt, tablefmt1=tablefmt1, tablefmt2=tablefmt,
                     width=width, param_widths=param_widths, **kwds))
                     for k, v in self.getColumnMap().items()) + \
                 '})'
+
+        s, last = make_title_meta_l0(self, level=level, width=width, heavy=heavy,
+                                     tablefmt=tablefmt, tablefmt1=tablefmt1,
+                                     tablefmt2=tablefmt2, center=center, excpt=['description'])
+        width = len(last)-1
+        if level == 0:
+            d = 'DATA'.center(width) + '\n' + '----'.center(width) + '\n'
         else:
-            s += mstr(self.__getstate__(), level=level,
-                      tablefmt=tablefmt, tablefmt1=tablefmt1, tablefmt2=tablefmt2,
-                      excpt=['description'], **kwds)
+            d = ''
         stp = 2 if level > 1 else 20 if level == 1 else None
         cols = self.getData().values()
 
         coldata = [list(itertools.islice(x.data, stp)) for x in cols]
-        d = cn + 'type-dataset =\n'
+
         nmun = zip((str(x) for x in self.getData().keys()),
                    (str(x.unit) for x in cols))
         hdr = list('%s\n(%s)' % nu for nu in nmun)
         d += matprint(coldata, trans=trans, headers=hdr,
                       tablefmt=tablefmt, tablefmt1=tablefmt1,
-                      tablefmt2=tablefmt2, **kwds)
+                      tablefmt2=tablefmt2, center=center, **kwds)
         collen = self.getRowCount()
         if level and stp < collen:
             d += '(Only display %d rows of %d for level=%d.)' % (stp, collen, level)
-        return f'{s}\n{d}{"="*80}\n\n'
+        return f'{s}\n{d}{last}\n'
 
     def __getstate__(self):
         """ Can be encoded with serializableEncoder """
         return OrderedDict(
-            meta=getattr(self, '_meta', None),
-            data=self.getData(),
+            _ATTR_meta=getattr(self, '_meta', None),
+            **self.getData(),
             _STID=self._STID)
 
 
@@ -621,6 +638,6 @@ class IndexedTableDataset(Indexed, TableDataset):
         # except (AttributeError, KeyError):
         #     description = None
         return Indexed.__getstate__(self).update(
-            meta=getattr(self, '_meta', None),
-            data=self.getData(),
+            _ATTR_meta=getattr(self, '_meta', None),
+            **self.getData(),
             _STID=self._STID)
