@@ -51,7 +51,6 @@ def get_registered_pools():
 
 # @ pools_api.route('', methods=['GET'])
 @ pools_api.route('/pools/', methods=['GET'])
-# #@ swag_from(endp['/pools']['get'])
 def get_pools():
     logger = current_app.logger
     if request.method in ['POST', 'PUT', 'DELETE'] and auth.current_user() == current_app.config['PC']['node']['ro_username']:
@@ -76,6 +75,7 @@ def get_name_all_pools(path):
     """
 
     alldirs = []
+    os.makedirs(path, exist_ok=True)
     allfilelist = os.listdir(path)
     for file in allfilelist:
         filepath = os.path.join(path, file)
@@ -84,6 +84,29 @@ def get_name_all_pools(path):
     current_app.logger.debug(path + ' has ' + str(alldirs))
     return alldirs
 
+
+######################################
+####  user/login /logout GET  ####
+######################################
+
+
+@ pools_api.route('/user/login', methods=['GET'])
+@ auth.login_required
+def login():
+    """ Logging in on the server.
+
+    :return: response made from http code, poolurl, message
+    """
+
+    logger = current_app.logger
+    __import__('pdb').set_trace()
+
+    msg = 'User %s logged-in Read-Write.' % auth.current_user().role
+    logger.debug(msg)
+
+    ts = time.time()
+    return resp(200, 'OK', msg, ts)
+
 ######################################
 #### /pools/register_all pools/register_all/  ####
 ######################################
@@ -226,12 +249,12 @@ def wipe_pools(poolnames=None):
     return good, notgood
 
 ######################################
-#### /{pool}  get_pool/  GET  ####
+#### /{pool}  /{pool}/  GET  ####
 ######################################
 
 
 @ pools_api.route('/<string:pool>', methods=['GET'])
-# @ swag_from(endp['/{pool}']['get'])
+@ pools_api.route('/<string:pool>/', methods=['GET'])
 def get_pool(pool):
     """ Get information of the given pool.
 
@@ -256,22 +279,27 @@ def get_pool_info(poolname, serialize_out=True):
 
     allpools = get_name_all_pools(current_app.config['POOLPATH_BASE'])
     if poolname in allpools:
-        code, result, mes = load_single_HKdata(
-            [poolname, 'hk', 'classes'],
-            serialize_out=serialize_out)
-        msg = 'Getting pool %s info.. %s.' % (poolname, mes)
+        code, result, mes = load_HKdata([poolname], serialize_out=True)
+        # use json.loads to avoid _STID for human
+        result = json.loads(result)
+        print(result['classes'])
+        # for n in ['classes', 'urns', 'tags']:
+        #    del result[n]['_STID']
+        for u in result['urns']:
+            del (result['urns'][u])['meta']
+        msg = 'Getting pool %s information. %s.' % (poolname, mes)
     else:
         code, result, msg = 404, FAILED, poolname +\
             ' is not an exisiting Pool ID.'
-    return 0, resp(code, result, msg, ts, serialize_out), 0
+    return 0, resp(code, result, msg, ts, False), 0
+
 
 ######################################
 ####  {pooolid}/register PUT /unreg DELETE  ####
 ######################################
 
-
+@auth.login_required
 @ pools_api.route('/<string:pool>', methods=['PUT'])
-# @ swag_from(endp['/{pool}']['put'])
 def register(pool):
     """ Register the given pool.
 
@@ -281,18 +309,13 @@ def register(pool):
     """
 
     logger = current_app.logger
-    if auth.current_user() == current_app.config['PC']['node']['ro_username']:
-        msg = 'User %s us Read-Only, not allowed to %s.' % \
-            (auth.current_user(), request.method)
-        logger.debug(msg)
-        return unauthorized(msg)
 
     ts = time.time()
     logger.debug('register pool ' + pool)
 
     code, thepool, msg = register_pool(pool)
-
-    return resp(code, thepool._poolurl, msg, ts)
+    res = thepool if issubclass(thepool.__class__, str) else thepool._poolurl
+    return resp(code, res, msg, ts)
 
 
 def register_pool(pool):
@@ -306,7 +329,7 @@ def register_pool(pool):
     try:
         po = PM.getPool(poolname=poolname, poolurl=poolurl)
         return 200, po, 'register pool ' + poolname + ' OK.'
-    except Exception as e:
+    except (ValueError, NotImplementedError) as e:
         code, result, msg = excp(
             e,
             msg='Unable to register pool: ' + poolname)
@@ -314,8 +337,8 @@ def register_pool(pool):
         return code, result, msg
 
 
+@ auth.login_required
 @ pools_api.route('/<string:pool>', methods=['DELETE'])
-# @ swag_from(endp['/{pool}']['delete'])
 def unregister(pool):
     """ Unregister this pool from PoolManager.
 
@@ -359,7 +382,7 @@ def unregister_pool(pool):
             result = 'FAILED'
             msg = 'Unable to unregister pool: ' + poolname
             code = 409
-        #current_app.logger.debug(f'{code}; {result}; {msg}')
+        # current_app.logger.debug(f'{code}; {result}; {msg}')
     except Exception as e:
         code, result, msg = excp(
             e,
@@ -375,7 +398,6 @@ def unregister_pool(pool):
 
 
 @ pools_api.route('/<string:pool>/hk/', methods=['GET'])
-# @ swag_from(endp['/{pool}']['put'])
 def hk(pool):
     """ All kinds of pool housekeeping data.
 
@@ -396,15 +418,14 @@ def load_HKdata(paths, serialize_out=True):
     """Load HKdata of a pool
     """
 
-    hkname = paths[-1]
-    poolname = '/'.join(paths[0: -1])
+    poolname = paths[0]
     poolurl = current_app.config['POOLURL_BASE'] + poolname
     # resourcetype = fullname(data)
 
     try:
         poolobj = PM.getPool(poolname=poolname, poolurl=poolurl)
         result = poolobj.readHK(serialize_out=serialize_out)
-        msg = ''
+        msg = 'OK.'
         code = 200
     except Exception as e:
         code, result, msg = excp(e, serialize_out=serialize_out)
@@ -616,6 +637,8 @@ def call_pool_Api(paths, serialize_out=False):
     msg = '%s(%s)' % (method, ', '.join(
         chain(map(str, args), kwdsexpr)))
     logger.debug('WebAPI ' + msg)
+    # if args and args[0] == 'select':
+    #    __import__('pdb').set_trace()
 
     poolname = paths[0]
     poolurl = current_app.config['POOLURL_BASE'] + poolname
